@@ -7,10 +7,11 @@ from pathlib import Path
 from mercury_engine_data_structures.file_tree_editor import OutputFormat
 
 from open_dread_rando import elevator, lua_util
-from open_dread_rando.exefs import patch_exefs
+from open_dread_rando.exefs import include_depackager, patch_exefs
 from open_dread_rando.logger import LOG
 from open_dread_rando.lua_editor import LuaEditor
 from open_dread_rando.map_icons import MapIconEditor
+from open_dread_rando.output_config import output_format_for_category, output_paths_for_compatibility
 from open_dread_rando.patcher_editor import PatcherEditor
 from open_dread_rando.pickup import pickup_object_for
 from open_dread_rando.static_fixes import apply_static_fixes
@@ -25,15 +26,6 @@ def _read_schema():
         return json.load(f)
 
 
-def _output_format_for_category(category: str) -> OutputFormat:
-    if category == "pkg":
-        return OutputFormat.PKG
-    elif category == "romfs":
-        return OutputFormat.ROMFS
-    else:
-        raise ValueError(f"unknown value: {category}")
-
-
 def create_custom_init(editor: PatcherEditor, configuration: dict):
     inventory: dict[str, int] = configuration["starting_items"]
     starting_location: dict = configuration["starting_location"]
@@ -148,10 +140,18 @@ def patch(input_path: Path, output_path: Path, configuration: dict):
     # Text patches
     if "text_patches" in configuration:
         apply_text_patches(editor, configuration["text_patches"])
+    
+
+    out_romfs, out_exefs, exefs_patches = output_paths_for_compatibility(output_path, configuration["mod_compatibility"])
+    output_format = output_format_for_category(configuration["mod_category"])
 
     # Exefs
     LOG.info("Creating exefs patches")
-    patch_exefs(output_path, configuration)
+    patch_exefs(exefs_patches, configuration)
+
+    if output_format == OutputFormat.ROMFS:
+        assert out_exefs is not None
+        include_depackager(out_exefs)
 
     LOG.info("Saving modified lua scripts")
     lua_scripts.save_modifications(editor)
@@ -160,12 +160,11 @@ def patch(input_path: Path, output_path: Path, configuration: dict):
     editor.flush_modified_assets()
 
     if configuration.get("debug_export_modified_files", False):
-        editor.save_modified_saves_to(output_path.joinpath("_debug"))
+        editor.save_modified_saves_to(out_romfs.parent.joinpath("_debug"))
 
-    out_romfs = output_path.joinpath("romfs")
     LOG.info("Saving modified pkgs to %s", out_romfs)
     shutil.rmtree(out_romfs, ignore_errors=True)
-    editor.save_modifications(out_romfs, output_format=_output_format_for_category(configuration["mod_category"]))
+    editor.save_modifications(out_romfs, output_format=output_format)
 
     LOG.info("Done")
 
